@@ -90,7 +90,7 @@ FLEXUNIT_SPACE = 1
 ##
 ##----------------------------------------------------------------------------------------------------------------------
 
-def UnitTests():
+def Flex_UnitTests():
     # Sense test classes
     classes = inspect.getmembers(sys.modules[__name__])
     classes = [ classobj for classname, classobj in classes if classname.startswith("Test") ]
@@ -151,7 +151,7 @@ class SenseTestCase(unittest.TestCase):
         cmdlen, ptnlen = len(commands), len(windowgramgroup_list)
         if cmdlen != ptnlen:
             raise Exception( "Mismatch: commands (" + str(cmdlen) + ") and windowgrams (" + str(ptnlen) + ")" )
-        wg = Windowgram( "1" ) # Specified in case the default changes
+        wg = Windowgram( NEW_WINDOWGRAM ) # Specified in case the default changes
         wlist = []
         for ix, (command, windowgram) in enumerate( zip( commands, windowgramgroup_list ) ):
             errors = flex_processor( wg, command, noticesok )
@@ -411,78 +411,22 @@ class Test_FlexCores(SenseTestCase):
         group_x = scalecore( group_i, 12, 3 )
         self.assertTrue( group_o == group_x )
 
-    ## Enforces the use of scale core v1, and will fail if v2 is reactivated.  See notes in scale core.
+    ## Enforces the use of scale core v1, and will fail if v2 is reactivated
 
-    def test_ScaleCoreDifference_CaseOne(self): # Created in flex using "new unittest ScaleCoreDifference_CaseOne"
+    def test_ScaleCore_VersionAssert(self):
         # break 1 2x2 ; scale 3x3 ; scale 2x2
         wg_i = "01\n23\n"
         wg_o = scalecore( wg_i, 3, 3 )
         wg_o = scalecore( wg_o, 2, 2 )
         self.assertTrue( wg_o == wg_i )
 
-    ## Tests the scale core multiple resizing that's necessary in some situations.  See notes in scale core.
-    ## TODO: Move this into the unit testing for the break command
+    ## Tests the need for retries in the scale core
 
-    def test_ScaleCoreDifference_CaseTwo(self): # Created in flex using "new unittest ScaleCoreDifference_CaseTwo"
-        # scale 42x42 ; break 1 6x6 ; break 1 3x3
-        self.assertFlexSequence( [
-            "scale 42x42 ; break 1 6x6 ; break 1 3x3",
-        ], """
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000111AAABBB222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000CCCDDDEEE222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            000000000FFFGGGHHH222222222333333333444444444555555555
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            666666666777777777888888888999999999aaaaaaaaabbbbbbbbb
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            cccccccccdddddddddeeeeeeeeefffffffffggggggggghhhhhhhhh
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            iiiiiiiiijjjjjjjjjkkkkkkkkklllllllllmmmmmmmmmnnnnnnnnn
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            ooooooooopppppppppqqqqqqqqqrrrrrrrrrsssssssssttttttttt
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-            uuuuuuuuuvvvvvvvvvwwwwwwwwwxxxxxxxxxyyyyyyyyyzzzzzzzzz
-        """ )
+    def test_ScaleCore_ScaleRetries(self):
+        # break 1 11x1 ; scale 46 1 ; break 5 7x1
+        wg_x = "00000001111111222222222333333344444445555555666666677777778888888889999999aaaaaaa\n"
+        wg_o = scalecore( "000011112222233334444555566667777888889999aaaa\n", 80, 1, ( "5", 7, 1 ) )
+        self.assertTrue( wg_o == wg_x )
 
     ## Group Core
 
@@ -820,6 +764,23 @@ class Test_FlexCores(SenseTestCase):
 
 
 
+##----------------------------------------------------------------------------------------------------------------------
+##
+## Unit Testing :: Flex Modifier :: Reset
+##
+##----------------------------------------------------------------------------------------------------------------------
+
+class Test_FlexModifier_Reset(SenseTestCase):
+
+    def test_Reset(self):
+        self.assertFlexSequence( [
+            "reset",
+        ], """
+            1
+        """ )
+
+
+
 ##----------------------------------------------------------------------------------------------------------------------
 ##
 ## Unit Testing :: Flex Modifier :: Scale
@@ -1071,6 +1032,125 @@ class Test_FlexModifier_Add(SenseTestCase):
 
 
 
+##----------------------------------------------------------------------------------------------------------------------
+##
+## Unit Testing :: Flex Modifier :: Break
+##
+##----------------------------------------------------------------------------------------------------------------------
+
+class Test_FlexModifier_Break(SenseTestCase):
+
+    def test_Break_Recursive(self): # Created in flex using "new unittest Break_Recursive"
+        self.assertFlexSequence( [
+            "break 1 3x2 Q",
+            "break R 3x2 q",
+            "break r 3x2 1",
+            "break 2 2x2 e",
+        ], """
+            QRS QQQqrsSSS QQQQQQQQQqqq123sssSSSSSSSSS QQQQQQQQQQQQQQQQQQqqqqqq11ef33ssssssSSSSSSSSSSSSSSSSSS
+            TUV QQQtuvSSS QQQQQQQQQqqq456sssSSSSSSSSS QQQQQQQQQQQQQQQQQQqqqqqq11gh33ssssssSSSSSSSSSSSSSSSSSS
+                TTTUUUVVV QQQQQQQQQtttuuuvvvSSSSSSSSS QQQQQQQQQQQQQQQQQQqqqqqq445566ssssssSSSSSSSSSSSSSSSSSS
+                TTTUUUVVV QQQQQQQQQtttuuuvvvSSSSSSSSS QQQQQQQQQQQQQQQQQQqqqqqq445566ssssssSSSSSSSSSSSSSSSSSS
+                          TTTTTTTTTUUUUUUUUUVVVVVVVVV QQQQQQQQQQQQQQQQQQttttttuuuuuuvvvvvvSSSSSSSSSSSSSSSSSS
+                          TTTTTTTTTUUUUUUUUUVVVVVVVVV QQQQQQQQQQQQQQQQQQttttttuuuuuuvvvvvvSSSSSSSSSSSSSSSSSS
+                          TTTTTTTTTUUUUUUUUUVVVVVVVVV QQQQQQQQQQQQQQQQQQttttttuuuuuuvvvvvvSSSSSSSSSSSSSSSSSS
+                          TTTTTTTTTUUUUUUUUUVVVVVVVVV QQQQQQQQQQQQQQQQQQttttttuuuuuuvvvvvvSSSSSSSSSSSSSSSSSS
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+                                                      TTTTTTTTTTTTTTTTTTUUUUUUUUUUUUUUUUUUVVVVVVVVVVVVVVVVVV
+        """ )
+
+    def test_Break_Scale(self): # Created in flex using "new unittest Break_Scale"
+        self.assertFlexSequence( [
+            "break 1 4x2 G ; scale 2x",
+            "break G 3x1 a",
+            "break H 4x1 d",
+            "break I 5x1 h",
+            "break J 3x1 m",
+            "break K 1x3 x",
+            "break L 1x3 X",
+            "break a 1x3 Q",
+        ], """
+            GGHHIIJJ abcHHHIIIJJJ abbcdefgIIIIJJJJ abbbcdeefghijklJJJJJ abbbbcdeeefghijjklmmnnoo
+            GGHHIIJJ abcHHHIIIJJJ abbcdefgIIIIJJJJ abbbcdeefghijklJJJJJ abbbbcdeeefghijjklmmnnoo
+            KKLLMMNN KKKLLLMMMNNN KKKKLLLLMMMMNNNN KKKKKLLLLLMMMMMNNNNN KKKKKKLLLLLLMMMMMMNNNNNN
+            KKLLMMNN KKKLLLMMMNNN KKKKLLLLMMMMNNNN KKKKKLLLLLMMMMMNNNNN KKKKKKLLLLLLMMMMMMNNNNNN
+
+            abbbbcdeeefghijjklmmnnoo abbbbcdeeefghijjklmmnnoo Qbbbbcdeeefghijjklmmnnoo
+            abbbbcdeeefghijjklmmnnoo abbbbcdeeefghijjklmmnnoo Rbbbbcdeeefghijjklmmnnoo
+            abbbbcdeeefghijjklmmnnoo abbbbcdeeefghijjklmmnnoo Sbbbbcdeeefghijjklmmnnoo
+            xxxxxxLLLLLLMMMMMMNNNNNN xxxxxxXXXXXXMMMMMMNNNNNN xxxxxxXXXXXXMMMMMMNNNNNN
+            yyyyyyLLLLLLMMMMMMNNNNNN yyyyyyYYYYYYMMMMMMNNNNNN yyyyyyYYYYYYMMMMMMNNNNNN
+            zzzzzzLLLLLLMMMMMMNNNNNN zzzzzzZZZZZZMMMMMMNNNNNN zzzzzzZZZZZZMMMMMMNNNNNN
+        """ )
+
+    def test_Break_Various(self): # Created in flex using "new unittest Break_Various"
+        self.assertFlexSequence( [
+            "break 1 7x4 a",
+            "break A 3x3 0",
+            "break B 5x2 A",
+            "break J 1x1 Z",
+            "break k 3x2 OQSUWY",
+        ], """
+            abcdefg aaabbbcccdddeeefffggg aaaaabbbbbcccccdddddeeeeefffffggggg aaaaabbbbbcccccdddddeeeeefffffggggg
+            hijklmn aaabbbcccdddeeefffggg aaaaabbbbbcccccdddddeeeeefffffggggg aaaaabbbbbcccccdddddeeeeefffffggggg
+            opqrstu aaabbbcccdddeeefffggg aaaaabbbbbcccccdddddeeeeefffffggggg aaaaabbbbbcccccdddddeeeeefffffggggg
+            vwxyzAB hhhiiijjjkkklllmmmnnn aaaaabbbbbcccccdddddeeeeefffffggggg aaaaabbbbbcccccdddddeeeeefffffggggg
+                    hhhiiijjjkkklllmmmnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn
+                    hhhiiijjjkkklllmmmnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn
+                    ooopppqqqrrrssstttuuu hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn
+                    ooopppqqqrrrssstttuuu hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn hhhhhiiiiijjjjjkkkkklllllmmmmmnnnnn
+                    ooopppqqqrrrssstttuuu ooooopppppqqqqqrrrrrssssstttttuuuuu ooooopppppqqqqqrrrrrssssstttttuuuuu
+                    vvvwwwxxxyyyzzz012BBB ooooopppppqqqqqrrrrrssssstttttuuuuu ooooopppppqqqqqrrrrrssssstttttuuuuu
+                    vvvwwwxxxyyyzzz345BBB ooooopppppqqqqqrrrrrssssstttttuuuuu ooooopppppqqqqqrrrrrssssstttttuuuuu
+                    vvvwwwxxxyyyzzz678BBB ooooopppppqqqqqrrrrrssssstttttuuuuu ooooopppppqqqqqrrrrrssssstttttuuuuu
+                                          vvvvvwwwwwxxxxxyyyyyzzzzz00122ABCDE vvvvvwwwwwxxxxxyyyyyzzzzz00122ABCDE
+                                          vvvvvwwwwwxxxxxyyyyyzzzzz33455ABCDE vvvvvwwwwwxxxxxyyyyyzzzzz33455ABCDE
+                                          vvvvvwwwwwxxxxxyyyyyzzzzz33455FGHIJ vvvvvwwwwwxxxxxyyyyyzzzzz33455FGHIZ
+                                          vvvvvwwwwwxxxxxyyyyyzzzzz66788FGHIJ vvvvvwwwwwxxxxxyyyyyzzzzz66788FGHIZ
+
+            aaaaaabbbbbbccccccddddddeeeeeeffffffgggggg
+            aaaaaabbbbbbccccccddddddeeeeeeffffffgggggg
+            aaaaaabbbbbbccccccddddddeeeeeeffffffgggggg
+            aaaaaabbbbbbccccccddddddeeeeeeffffffgggggg
+            hhhhhhiiiiiijjjjjjOOQQSSllllllmmmmmmnnnnnn
+            hhhhhhiiiiiijjjjjjOOQQSSllllllmmmmmmnnnnnn
+            hhhhhhiiiiiijjjjjjUUWWYYllllllmmmmmmnnnnnn
+            hhhhhhiiiiiijjjjjjUUWWYYllllllmmmmmmnnnnnn
+            ooooooppppppqqqqqqrrrrrrssssssttttttuuuuuu
+            ooooooppppppqqqqqqrrrrrrssssssttttttuuuuuu
+            ooooooppppppqqqqqqrrrrrrssssssttttttuuuuuu
+            ooooooppppppqqqqqqrrrrrrssssssttttttuuuuuu
+            vvvvvvwwwwwwxxxxxxyyyyyyzzzzzz001122ABCCDE
+            vvvvvvwwwwwwxxxxxxyyyyyyzzzzzz334455ABCCDE
+            vvvvvvwwwwwwxxxxxxyyyyyyzzzzzz334455FGHHIZ
+            vvvvvvwwwwwwxxxxxxyyyyyyzzzzzz667788FGHHIZ
+        """ )
+
+    def test_Break_Naming(self): # Created in flex using "new unittest Break_Naming"
+        self.assertFlexSequence( [
+            "break 1 6x2 Z",
+            "break a 13x2",
+            "break Z 13x2",
+        ], """
+            Z01234 ZZZZZZZZZZZZZ00000000000001111111111111222222222222233333333333334444444444444
+            56789a ZZZZZZZZZZZZZ00000000000001111111111111222222222222233333333333334444444444444
+                   55555555555556666666666666777777777777788888888888889999999999999abcdefghijklm
+                   55555555555556666666666666777777777777788888888888889999999999999nopqrstuvwxyz
+
+            ABCDEFGHIJKLM00000000000001111111111111222222222222233333333333334444444444444
+            NOPQRSTUVWXYZ00000000000001111111111111222222222222233333333333334444444444444
+            55555555555556666666666666777777777777788888888888889999999999999abcdefghijklm
+            55555555555556666666666666777777777777788888888888889999999999999nopqrstuvwxyz
+        """ )
+
+
+
 ##----------------------------------------------------------------------------------------------------------------------
 ##
 ## Unit Testing :: Flex Modifier :: Drag
@@ -1079,18 +1159,6 @@ class Test_FlexModifier_Add(SenseTestCase):
 
 class Test_FlexModifier_Drag(SenseTestCase):
 
-    def test_Drag_EdgeMorphing(self): # Created in flex using "new unittest Drag_EdgeMorphing"
-        self.assertFlexSequence( [
-            "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
-        ], """
-            zzzzT3
-            yyyS23
-            xxR123
-            wQ0123
-            XY0123
-        """ )
-
-    # Ignore notices
     def test_Drag_EdgeModify_Example1(self): # Created in flex using "new unittest Drag_EdgeModify_Example1"
         self.assertFlexSequence( [
             "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
@@ -1101,9 +1169,8 @@ class Test_FlexModifier_Drag(SenseTestCase):
             xxR123 xxRRRR
             wQ0123 wQQQQQ
             XY0123 XXXXXX
-        """, True )
+        """, True ) # Ignore notices
 
-    # Ignore notices
     def test_Drag_EdgeModify_Example2(self): # Created in flex using "new unittest Drag_EdgeModify_Example2"
         self.assertFlexSequence( [
             "break 1 6x5 a ; join Au.0 Bvp.1 Cwqk.2 Dxrlf.3 s.w t.Q mn.x o.R ghi.y j.S abcd.z e.T y.X z.Y",
@@ -1114,9 +1181,8 @@ class Test_FlexModifier_Drag(SenseTestCase):
             xxR123 xxRRRR
             wQ0123 wQQQQQ
             XY0123 XXXYYY
-        """, True )
+        """, True ) # Ignore notices
 
-    # Ignore notices
     def test_Drag_EdgeModify_WithScale(self): # Created in flex using "new unittest Drag_EdgeModify_WithScale"
         self.assertFlexSequence( [
             "break 1 9x6 ; join RIzqh8 QHypg PGxo OFw NE",
@@ -1130,9 +1196,8 @@ class Test_FlexModifier_Drag(SenseTestCase):
             rstuvOPQR rstuvvvvv
             ABCDNOPQR AAABBBCCC
             JKLMNOPQR JJJKKKLLL
-        """, True )
+        """, True ) # Ignore notices
 
-    # Ignore notices
     def test_Drag_EdgeModify_NoScale(self): # Created in flex using "new unittest Drag_EdgeModify_NoScale"
         self.assertFlexSequence( [
             "break 1 7x7 ; join 18fm 29g 3a MFyrkd6 LExqjc KDwpi JCvo IBu HA",
@@ -1147,9 +1212,8 @@ class Test_FlexModifier_Drag(SenseTestCase):
             stIJKLM stIIIIIIIII
             zHIJKLM zHIIIIIIIII
             GHIJKLM GHIIIIIIIII
-        """, True )
+        """, True ) # Ignore notices
 
-    # Ignore notices
     def test_Drag_Expansion_Right(self): # Created in flex using "new unittest Drag_Expansion_Right"
         self.assertFlexSequence( [
             "break 1 2x3 o ; scale 2x:1x",
@@ -1158,7 +1222,193 @@ class Test_FlexModifier_Drag(SenseTestCase):
             oopp ooppppp
             qqrr qqqqqqq
             sstt ssttttt
-        """, True )
+        """, True ) # Ignore notices
+
+    # Released 2.16 without sufficient unit testing; found and fixed the following bugs
+
+    def test_Drag_Fixed1(self): # Created in flex using "new unittest Drag_Fixed1"
+        self.assertFlexSequence( [
+            "break 1 2x2 1 ; scale 5x",
+            "drag horizontal 1234 down 4",
+            "drag horizontal 1234 down 3",
+        ], """
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 3333344444 1111122222
+                                  1111122222
+                                  1111122222
+        """, True ) # Ignore notices
+
+    def test_Drag_Fixed2(self): # Created in flex using "new unittest Drag_Fixed2"
+        self.assertFlexSequence( [
+            "break 1 2x2 1 ; scale 5x",
+            "drag horizontal 1234 down 4",
+            "drag horizontal 1234 up 2",
+        ], """
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            1111122222 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 1111122222 1111122222
+            3333344444 1111122222 3333344444
+            3333344444 1111122222 3333344444
+            3333344444 3333344444 3333344444
+        """ )
+
+    def test_Drag_Fixed3(self): # Created in flex using "new unittest Drag_Fixed3"
+        self.assertFlexSequence( [
+            "scale 36x10 ; break 1 6x2 defghiDEFGHI ; drag r iI l 3",
+            "drag bottom ghi down 4",
+            "drag horizontal ghiGHI up 1",
+        ], """
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII
+        """ )
+
+    # Enforce required sorted() of edge overlap in the edgemagnet() function to prevent careless removal
+
+    def test_Drag_Overlap(self): # Created in flex using "new unittest Drag_Overlap"
+        self.assertFlexSequence( [
+            "scale 36x10 ; break 1 6x2 defghiDEFGHI ; drag r iI l 3",
+            "drag bottom ghi down 4",
+            "drag bottom ghi up 1",
+        ], """
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii ddddddeeeeeeffffffgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFgggggghhhhhhiii
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFgggggghhhhhhiii DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII
+            DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII DDDDDDEEEEEEFFFFFFGGGGGGHHHHHHIII
+        """ )
+
+    # Mixing edgegroup with scalegroup to make sure the intended edge is dragged when multiple panes factor
+
+    def test_Drag_EdgeScaleMixing(self): # Created in flex using "new unittest Drag_EdgeScaleMixing"
+        self.assertFlexSequence( [
+            "scale 12x4 ; break 1 4x2 wxyzWXYZ",
+            "drag bottom x:yXY down 1",
+            "drag top Y:Xxy up 2",
+            "drag horizontal XYxy down 2",
+            "drag top XY:xy up 1 ; drag left Z:xyzXY right 2",
+            "drag right wW:xyXY left 2",
+            "drag vertical ZY:xXyz left 2",
+            "drag vertical wxWX:yY right 2",
+        ], """
+            wwwxxxyyyzzz wwwxxxyyyzzz wwwxxxyyyzzz wwwxxxyyyzzz wwwxxxxyyyyz wxxxxxyyyyyz wxxxxyyyyzzz wwwxxxyyyzzz
+            wwwxxxyyyzzz wwwxxxyyyzzz wwwXXXYYYzzz wwwxxxyyyzzz wwwxxxxyyyyz wxxxxxyyyyyz wxxxxyyyyzzz wwwxxxyyyzzz
+            WWWXXXYYYZZZ WWWxxxyyyZZZ WWWXXXYYYZZZ WWWxxxyyyZZZ WWWXXXXYYYYZ WXXXXXYYYYYZ WXXXXYYYYZZZ WWWXXXYYYZZZ
+            WWWXXXYYYZZZ WWWXXXYYYZZZ WWWXXXYYYZZZ WWWXXXYYYZZZ WWWXXXXYYYYZ WXXXXXYYYYYZ WXXXXYYYYZZZ WWWXXXYYYZZZ
+        """ )
+
+    # Other tests
+
+    def test_Drag_ExpandAndContract(self): # Created in flex using "new unittest Drag_ExpandAndContract"
+        self.assertFlexSequence( [
+            "scale 12x4 ; break 1 4x2 wxyzWXYZ",
+            "drag bottom X:* down 2",
+            "drag right z:* right 4",
+            "drag top y:* down 2",
+            "drag left w:* right 4",
+            "drag bottom * up 2",
+            "drag right * left 8",
+            "drag top * up 2",
+            "drag left * left 8",
+        ], """
+            wwwxxxyyyzzz wwwxxxyyyzzz wwwwxxxxyyyyzzzz wwwwxxxxyyyyzzzz wwwxxxyyyzzz wwwxxxyyyzzz wxyz wxyz wwwxxxyyyzzz
+            wwwxxxyyyzzz wwwxxxyyyzzz wwwwxxxxyyyyzzzz wwwwxxxxyyyyzzzz wwwxxxyyyzzz WWWXXXYYYZZZ WXYZ wxyz wwwxxxyyyzzz
+            WWWXXXYYYZZZ wwwxxxyyyzzz wwwwxxxxyyyyzzzz WWWWXXXXYYYYZZZZ WWWXXXYYYZZZ                   WXYZ WWWXXXYYYZZZ
+            WWWXXXYYYZZZ WWWXXXYYYZZZ WWWWXXXXYYYYZZZZ WWWWXXXXYYYYZZZZ WWWXXXYYYZZZ                   WXYZ WWWXXXYYYZZZ
+                         WWWXXXYYYZZZ WWWWXXXXYYYYZZZZ
+                         WWWXXXYYYZZZ WWWWXXXXYYYYZZZZ
+        """ )
+
+    def test_Drag_WithAndWithoutScalegroup(self): # Created in flex using "new unittest Drag_WithAndWithoutScalegroup"
+        self.assertFlexSequence( [
+            "break 1 4x4 A ; scale 4x",
+            "drag left G:* left 4",
+            "drag bottom G:* down 4",
+            "drag left G left 1",
+            "drag bottom G down 1",
+            "drag right G right 2",
+        ], """
+            AAAABBBBCCCCDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            AAAABBBBCCCCDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            AAAABBBBCCCCDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            AAAABBBBCCCCDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            EEEEFFFFGGGGHHHH EEFFGGGGGGHHHHHH AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            EEEEFFFFGGGGHHHH EEFFGGGGGGHHHHHH AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD AABBCCCCCCDDDDDD
+            EEEEFFFFGGGGHHHH EEFFGGGGGGHHHHHH EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            EEEEFFFFGGGGHHHH EEFFGGGGGGHHHHHH EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            IIIIJJJJKKKKLLLL IIJJKKKKKKLLLLLL EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            IIIIJJJJKKKKLLLL IIJJKKKKKKLLLLLL EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            IIIIJJJJKKKKLLLL IIJJKKKKKKLLLLLL EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            IIIIJJJJKKKKLLLL IIJJKKKKKKLLLLLL EEFFGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGHHHHHH EEFGGGGGGGGGHHHH
+            MMMMNNNNOOOOPPPP MMNNOOOOOOPPPPPP IIJJKKKKKKLLLLLL IIJJKKKKKKLLLLLL IIFGGGGGGGLLLLLL IIFGGGGGGGGGLLLL
+            MMMMNNNNOOOOPPPP MMNNOOOOOOPPPPPP IIJJKKKKKKLLLLLL IIJJKKKKKKLLLLLL IIJJKKKKKKLLLLLL IIJJKKKKKKKKLLLL
+            MMMMNNNNOOOOPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP
+            MMMMNNNNOOOOPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP MMNNOOOOOOPPPPPP
+        """ )
+
+    def test_Drag_AcrossWindowgramEdge(self): # Created in flex using "new unittest Drag_AcrossWindowgramEdge"
+        self.assertFlexSequence( [
+            "scale 12 ; break 1 4x4 A",
+            "drag right F left 150%",
+            "reset ; scale 12 ; break 1 4x4 A ; drag right F right 150%",
+            "reset ; scale 12 ; break 1 4x4 A ; drag bottom G up 150%",
+            "reset ; scale 12 ; break 1 4x4 A ; drag bottom G down 150%",
+        ], """
+            AAABBBCCCDDD AAAAAABBBCCCDDD AAABBBCCCDDDDDD AAABBBKKKDDD AAABBBCCCDDD
+            AAABBBCCCDDD AAAAAABBBCCCDDD AAABBBCCCDDDDDD AAABBBKKKDDD AAABBBCCCDDD
+            AAABBBCCCDDD AAAAAABBBCCCDDD AAABBBCCCDDDDDD AAABBBKKKDDD AAABBBCCCDDD
+            EEEFFFGGGHHH GGGGGGGGGGGGHHH EEEFFFFFFFFFFFF AAABBBKKKDDD EEEFFFGGGHHH
+            EEEFFFGGGHHH GGGGGGGGGGGGHHH EEEFFFFFFFFFFFF AAABBBKKKDDD EEEFFFGGGHHH
+            EEEFFFGGGHHH GGGGGGGGGGGGHHH EEEFFFFFFFFFFFF AAABBBKKKDDD EEEFFFGGGHHH
+            IIIJJJKKKLLL IIIIIIJJJKKKLLL IIIJJJKKKLLLLLL EEEFFFKKKHHH IIIJJJGGGLLL
+            IIIJJJKKKLLL IIIIIIJJJKKKLLL IIIJJJKKKLLLLLL EEEFFFKKKHHH IIIJJJGGGLLL
+            IIIJJJKKKLLL IIIIIIJJJKKKLLL IIIJJJKKKLLLLLL EEEFFFKKKHHH IIIJJJGGGLLL
+            MMMNNNOOOPPP MMMMMMNNNOOOPPP MMMNNNOOOPPPPPP IIIJJJKKKLLL MMMNNNGGGPPP
+            MMMNNNOOOPPP MMMMMMNNNOOOPPP MMMNNNOOOPPPPPP IIIJJJKKKLLL MMMNNNGGGPPP
+            MMMNNNOOOPPP MMMMMMNNNOOOPPP MMMNNNOOOPPPPPP IIIJJJKKKLLL MMMNNNGGGPPP
+                                                         MMMNNNOOOPPP MMMNNNGGGPPP
+                                                         MMMNNNOOOPPP MMMNNNGGGPPP
+                                                         MMMNNNOOOPPP MMMNNNGGGPPP
+        """, True ) # Ignore notices
+
+#    def test_Drag_MultipleEdges(self): # Created in flex using "new unittest Drag_MultipleEdges"
+#        self.assertFlexSequence( [
+#            "scale 15x8 ; break 1 3x4 defDEFGHIghi",
+#            "drag b D:dGgFfIi down 2",
+#        ], """
+#            dddddeeeeefffff dddddeeeeefffff
+#            dddddeeeeefffff dddddeeeeefffff
+#            DDDDDEEEEEFFFFF dddddEEEEEfffff
+#            DDDDDEEEEEFFFFF DDDDDEEEEEFFFFF
+#            GGGGGHHHHHIIIII DDDDDHHHHHFFFFF
+#            GGGGGHHHHHIIIII DDDDDHHHHHFFFFF
+#            ggggghhhhhiiiii GGGGGhhhhhIIIII
+#            ggggghhhhhiiiii ggggghhhhhiiiii
+#        """ )
 
 
 
@@ -1176,15 +1426,36 @@ class Test_FlexModifier_Drag(SenseTestCase):
 
 ##----------------------------------------------------------------------------------------------------------------------
 ##
-## Unit Testing :: Flex Modifier Combination :: AddBreakJoin
-##
-## This asserts the underlying pane order of [0-9a-zA-Z] through default name assignment of the Add command.  It must
-## follow the commands it depends upon: add, break, and join.
+## Unit Testing :: Flex Modifier Combinations
 ##
 ##----------------------------------------------------------------------------------------------------------------------
 
+class Test_FlexModifierCombination_ScaleCoreDetails(SenseTestCase):
+
+    ## These two tests were already done in a more direct form earlier in the core area
+
+    def test_ScaleCoreDetails_VersionAssert(self): # Created in flex using "new unittest ScaleCoreDetails_VersionAssert"
+        # break 1 2x2 ; scale 3x3 ; scale 2x2
+        self.assertFlexSequence( [
+            "break 1 2x2 ; scale 3x3 ; scale 2x2",
+        ], """
+            01
+            23
+        """ )
+
+    def test_ScaleCoreDetails_ScaleRetries(self): # Created in flex using "new unittest ScaleCoreDetails_ScaleRetries"
+        # See this commit for the code used to discover this test
+        # break 1 11x1 ; scale 46 1 ; break 5 7x1
+        self.assertFlexSequence( [
+            "break 1 11x1 ; scale 46 1 ; break 5 7x1",
+        ], """
+            00000001111111222222222333333344444445bcdefg666666677777778888888889999999aaaaaaa
+        """ )
+
 class Test_FlexModifierCombination_AddBreakJoin(SenseTestCase):
 
+    ## This asserts the underlying pane order of [0-9a-zA-Z] through default name assignment of the Add command
+
     def test_AddBreakJoin_DefaultNames(self): # Created in flex using "new unittest AddBreakJoin_DefaultNames"
         self.assertFlexSequence( [
             "break 1 31x2 ; join 210 ba BA YZ",
@@ -1250,6 +1521,7 @@ class Test_ReadmeDemonstrations(SenseTestCase):
             "split 1 bottom 3 s",
             "rename Nn Dd",
             "swap z s Ll Dd",
+            "drag left BDLbdl left 50%",
         ], """
             1111111111111111111111111zzzzzzzzzzzz 1111111111111111111111111zzzzzzzzzzzz
             1111111111111111111111111zzzzzzzzzzzz 1111111111111111111111111zzzzzzzzzzzz
@@ -1272,6 +1544,17 @@ class Test_ReadmeDemonstrations(SenseTestCase):
             sssssssssssssssssssssssssbbbblllldddd zzzzzzzzzzzzzzzzzzzzzzzzzbbbbddddllll
             sssssssssssssssssssssssssbbbblllldddd zzzzzzzzzzzzzzzzzzzzzzzzzbbbbddddllll
             sssssssssssssssssssssssssbbbblllldddd zzzzzzzzzzzzzzzzzzzzzzzzzbbbbddddllll
+
+            1111111111111ssssssssssssssssssssssss
+            1111111111111ssssssssssssssssssssssss
+            1111111111111BBBBBBBBDDDDDDDDLLLLLLLL
+            1111111111111BBBBBBBBDDDDDDDDLLLLLLLL
+            1111111111111BBBBBBBBDDDDDDDDLLLLLLLL
+            1111111111111BBBBBBBBDDDDDDDDLLLLLLLL
+            1111111111111bbbbbbbbddddddddllllllll
+            zzzzzzzzzzzzzbbbbbbbbddddddddllllllll
+            zzzzzzzzzzzzzbbbbbbbbddddddddllllllll
+            zzzzzzzzzzzzzbbbbbbbbddddddddllllllll
         """ )
 
 
